summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAdrian Holovaty <adrian@holovaty.com>2012-04-27 22:37:59 -0500
committerAdrian Holovaty <adrian@holovaty.com>2012-04-27 22:37:59 -0500
commit21f11e5280696560dbd98b7acd54b762e095d810 (patch)
tree292b5ef29ba6633440bbf4ff31557cde7a1c4dee
parent8df8e516ab9d6eb1f86e4f814a479242402e1ffd (diff)
Updated compilemessages and makemessages management commands to change SVN->Git references
-rw-r--r--django/core/management/commands/compilemessages.py2
-rw-r--r--django/core/management/commands/makemessages.py6
2 files changed, 4 insertions, 4 deletions
diff --git a/django/core/management/commands/compilemessages.py b/django/core/management/commands/compilemessages.py
index b5eaeb1f52..4118fd036d 100644
--- a/django/core/management/commands/compilemessages.py
+++ b/django/core/management/commands/compilemessages.py
@@ -21,7 +21,7 @@ def compile_messages(stderr, locale=None):
basedirs = set(map(os.path.abspath, filter(os.path.isdir, basedirs)))
if not basedirs:
- raise CommandError("This script should be run from the Django SVN tree or your project or app tree, or with the settings module specified.")
+ raise CommandError("This script should be run from the Django Git checkout or your project or app tree, or with the settings module specified.")
for basedir in basedirs:
if locale:
diff --git a/django/core/management/commands/makemessages.py b/django/core/management/commands/makemessages.py
index 0b7505962d..b21cbce206 100644
--- a/django/core/management/commands/makemessages.py
+++ b/django/core/management/commands/makemessages.py
@@ -264,7 +264,7 @@ def make_messages(locale=None, domain='django', verbosity=1, all=False,
extensions=None, symlinks=False, ignore_patterns=None, no_wrap=False,
no_location=False, no_obsolete=False, stdout=sys.stdout):
"""
Uses the ``locale/`` directory from the Django SVN tree or an
application/project to process all files with translatable literals for
the :param domain: domain and :param locale: locale.
"""
@@ -287,9 +287,9 @@ def make_messages(locale=None, domain='django', verbosity=1, all=False,
elif os.path.isdir('locale'):
localedir = os.path.abspath('locale')
else:
- raise CommandError("This script should be run from the Django SVN "
+ raise CommandError("This script should be run from the Django Git "
"tree or your project or app tree. If you did indeed run it "
- "from the SVN checkout or your project or application, "
+ "from the Git checkout or your project or application, "
"maybe you are just missing the conf/locale (in the django "
"tree) or locale (for project and application) directory? It "
"is not created automatically, you have to create it by hand "
@@ -264,7 +264,7 @@ def make_messages(locale=None, domain='django', verbosity=1, all=False,
no_location=False, no_obsolete=False, stdout=sys.stdout):
"""
- Uses the ``locale/`` directory from the Django SVN tree or an
+ Uses the ``locale/`` directory from the Django Git tree or an
application/project to process all files with translatable literals for
the :param domain: domain and :param locale: locale.